# Library for Data Literate Bootcamp

Berisi illustrasi untuk materi Bootcamp OOP, Machine Learning, Supervised Learning, Linear Regression dan Naive Bayes.

## Cara Install

```bash
pip install BootcampDSC
```

shandytp - 7 Januari 2021